wurfl2python.WurflPythonWriter

Module wurfl2python :: Class WurflPythonWriter |
[hide private]
[frames] | no frames]

# Class WurflPythonWriter

source code

                               object --+
                                        |
    pywurfl.wurflprocessor.WurflProcessor --+
                                            |
                                           WurflPythonWriter

Instance Methods | [hide private]
__init__(self, wurflxml, device_handler=None, options=`{``'``outfile``'``:` `'``wurfl.py``'``}`) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
handle_device(self, devobj) Hook called to handle a device. | source code
process_options(self) Hook called to process any additional options. | source code
process_capability(self, devobj, group, capability) Hook called when a new WURFL capability is encountered. | source code
start_process(self) Hook called in before any processing is done. | source code
end_process(self) Hook called when processing is done. | source code
Inherited from `pywurfl.wurflprocessor.WurflProcessor`: `process`, `process_deferred`, `process_device`, `process_group`, `process_new_deferred` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, wurflxml, device_handler=None, options=`{``'``outfile``'``:` `'``wurfl.py``'``}`) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: pywurfl.wurflprocessor.WurflProcessor.__init__ (inherited documentation)

### handle_device(self, devobj) | source code
Hook called to handle a device. This hook is called when all of the capabilities of a device have been processed and its fall_back has already been processed. Overrides: pywurfl.wurflprocessor.WurflProcessor.handle_device (inherited documentation)

### process_options(self) | source code
Hook called to process any additional options. Overrides: pywurfl.wurflprocessor.WurflProcessor.process_options (inherited documentation)

### process_capability(self, devobj, group, capability) | source code
Hook called when a new WURFL capability is encountered. Overrides: pywurfl.wurflprocessor.WurflProcessor.process_capability (inherited documentation)

### start_process(self) | source code
Hook called in before any processing is done. Overrides: pywurfl.wurflprocessor.WurflProcessor.start_process (inherited documentation)

### end_process(self) | source code
Hook called when processing is done. Overrides: pywurfl.wurflprocessor.WurflProcessor.end_process (inherited documentation)